@@ -82,19 +82,25 @@ def check_dirs_existance(dir_or_dirs: str | list[str]) -> None:
         raise KeyError(f"Some paths were not found: {missing}")
 
 
-def make_dirs(dir_or_dirs: str | list[str]) -> None:
+def make_dirs(dir_or_dirs: str | list[str]) -> list[bool]:
     """
     Creates the specified dir_or_dirs if they do not already exist.
 
     Args:
         dir_or_dirs (str | list[str]): Directory or list of directory paths to create.
+    
+    Returns:
+        list[bool]: for each directory 'created', whether or not it existed before.
     """
     if isinstance(dir_or_dirs, str):
         dir_or_dirs = [dir_or_dirs]
 
+    existed = []
     for directory in dir_or_dirs:
+        existed.append(os.path.exists(directory))
         os.makedirs(directory, exist_ok=True)
 
+    return existed
 
 def clear_directories(dir_or_dirs: str | list[str], remove_folder: bool = False, verbose: bool = None):
     """Clears out each directory in `dir_or_dirs`. 
@@ -213,7 +219,7 @@ def change_file_ext(path: str, new_extension: str) -> str:
     return str(Path(path).with_suffix(new_extension))
 
 
-def manage_temp_files(call_key: str, temp_folder_path: str, function: Callable, _verbose: bool = None, *args, **kwargs) -> Any:
+def manage_temp_files(call_key: str, temp_folder_path: str, function: Callable, _verbose: bool = None, keep_logs: bool = True, *args, **kwargs) -> Any:
     """Manages temporal files for saving certain function outputs.
 
     When called for the first time, it will execute the function and save the file
@@ -249,7 +255,10 @@ def manage_temp_files(call_key: str, temp_folder_path: str, function: Callable,
         return load_json(temp_path, verbose=False)
 
     if get_verbose(_verbose):
-        print_status(f" - Executing '{function.__name__}' for '{call_key}'...")
+        if keep_logs:
+            print_log(f" - Executing '{function.__name__}' for '{call_key}'...")
+        else:
+            print_status(f" - Executing '{function.__name__}' for '{call_key}'...")
     result = function(*args, **kwargs)
 
     save_json(temp_path, result, verbose=False)
